pub struct FormItemControlContext { /* private fields */ }Implementations
Sourceimpl FormItemControlContext
impl FormItemControlContext
pub fn name(&self) -> &str
pub fn value(&self) -> Option<Value>
Sourcepub fn value_prop_name(&self) -> Option<&str>
pub fn value_prop_name(&self) -> Option<&str>
Optional metadata describing which prop should be treated as value when integrating with custom controls (similar to AntD’s valuePropName).
Sourcepub fn apply_mapped_value(&self, raw: Value)
pub fn apply_mapped_value(&self, raw: Value)
Apply a raw Value coming from a custom event, passing it through
get_value_from_event if configured, then writing it into FormStore.
pub fn set_value(&self, value: Value)
pub fn set_string(&self, value: impl Into<String>)
pub fn is_disabled(&self) -> bool