pub fn end_pointer(state: &mut Signal<PointerState>, evt: &PointerEvent)Expand description
Stop tracking when the active pointer finishes, releasing capture if present.
pub fn end_pointer(state: &mut Signal<PointerState>, evt: &PointerEvent)Stop tracking when the active pointer finishes, releasing capture if present.