pub fn is_active_pointer(
state: &Signal<PointerState>,
evt: &PointerEvent,
) -> boolExpand description
Whether the event belongs to the currently tracked pointer.
pub fn is_active_pointer(
state: &Signal<PointerState>,
evt: &PointerEvent,
) -> boolWhether the event belongs to the currently tracked pointer.