pub struct MessageApi { /* private fields */ }Expand description
Public API used by use_message() callers.
Implementations
Sourceimpl MessageApi
impl MessageApi
pub fn new(overlay: OverlayHandle, entries: MessageEntriesSignal) -> Self
Sourcepub fn open(&self, config: MessageConfig) -> OverlayKey
pub fn open(&self, config: MessageConfig) -> OverlayKey
Low-level open method that accepts a full config object.
pub fn info(&self, content: impl Into<String>) -> OverlayKey
pub fn success(&self, content: impl Into<String>) -> OverlayKey
pub fn warning(&self, content: impl Into<String>) -> OverlayKey
pub fn error(&self, content: impl Into<String>) -> OverlayKey
pub fn loading(&self, content: impl Into<String>) -> OverlayKey
Sourcepub fn destroy(&self, key: Option<OverlayKey>)
pub fn destroy(&self, key: Option<OverlayKey>)
Destroy a specific message or all messages when key is None.