pub struct OverlayHandle { /* private fields */ }Expand description
Handle used by components to interact with the overlay manager through a
Dioxus signal. This is designed to be provided once near the root of the
app (for example inside the future App component) and then consumed via
use_overlay in child components.
Implementations
Sourceimpl OverlayHandle
impl OverlayHandle
Sourcepub fn open(
&self,
kind: OverlayKind,
has_mask: bool,
) -> (OverlayKey, OverlayMeta)
pub fn open( &self, kind: OverlayKind, has_mask: bool, ) -> (OverlayKey, OverlayMeta)
Register a new overlay and receive its key and metadata.
Sourcepub fn update(
&self,
key: OverlayKey,
has_mask: Option<bool>,
) -> Option<OverlayMeta>
pub fn update( &self, key: OverlayKey, has_mask: Option<bool>, ) -> Option<OverlayMeta>
Update metadata for an existing overlay.
Sourcepub fn close(&self, key: OverlayKey)
pub fn close(&self, key: OverlayKey)
Close a specific overlay.
Sourcepub fn snapshot(&self) -> OverlayManager
pub fn snapshot(&self) -> OverlayManager
Snapshot the current manager state. This is intended for read-only operations such as rendering overlay layers.