pub struct TourStep {
pub key: String,
pub title: Option<String>,
pub description: Option<Element>,
pub cover: Option<Element>,
pub placement: Option<TooltipPlacement>,
pub target: Option<String>,
pub next_button_text: Option<String>,
pub prev_button_text: Option<String>,
}Expand description
Data model for a single tour step.
Fields
key: StringUnique key for the step.
title: Option<String>Title displayed in the tour panel.
description: Option<Element>Description text or element.
cover: Option<Element>Cover image or element displayed above the content.
placement: Option<TooltipPlacement>Placement of the tour panel relative to the target.
target: Option<String>CSS selector for the target element to highlight. When None, the panel is centered on screen.
Custom “Next” button text.
Custom “Previous” button text.
Implementations
Sourceimpl TourStep
impl TourStep
Sourcepub fn new(
key: impl Into<String>,
title: impl Into<String>,
description: impl Into<String>,
) -> Self
pub fn new( key: impl Into<String>, title: impl Into<String>, description: impl Into<String>, ) -> Self
Create a new tour step with title and description.
Sourcepub fn placement(self, placement: TooltipPlacement) -> Self
pub fn placement(self, placement: TooltipPlacement) -> Self
Set the placement of the tour panel.
Sourcepub fn description_element(self, desc: Element) -> Self
pub fn description_element(self, desc: Element) -> Self
Set custom description element.
Set custom next button text.
Set custom prev button text.