pub struct SemanticClassNames<S: Hash + Eq> { /* private fields */ }Expand description
A collection of CSS class names keyed by semantic slot name.
Used to customize the styling of specific parts of a component.
Example
ⓘ
use adui_dioxus::foundation::SemanticClassNames;
#[derive(Hash, Eq, PartialEq, Clone, Copy)]
enum ButtonSemantic {
Root,
Icon,
Content,
}
let mut class_names = SemanticClassNames::new();
class_names.set(ButtonSemantic::Root, "my-custom-button");
class_names.set(ButtonSemantic::Icon, "my-custom-icon");Implementations
Sourceimpl<S: Hash + Eq> SemanticClassNames<S>
impl<S: Hash + Eq> SemanticClassNames<S>
Sourcepub fn set(&mut self, slot: S, class_name: impl Into<String>)
pub fn set(&mut self, slot: S, class_name: impl Into<String>)
Set the class name for a specific semantic slot.
Sourcepub fn get(&self, slot: &S) -> Option<&str>
pub fn get(&self, slot: &S) -> Option<&str>
Get the class name for a specific semantic slot, if set.
Sourcepub fn get_or_empty(&self, slot: &S) -> &str
pub fn get_or_empty(&self, slot: &S) -> &str
Get the class name for a slot or return an empty string.